# Examples

This is a collection of code examples to allow for an easy exploration of the functionalities that BoFire offers.

## DoE

- [creating designs for constrained design spaces](basic_examples.ipynb)
- [optimizing designs with respect to various optimality criteria](optimality_criteria.ipynb)
- [creating designs for a custom model](design_with_explicit_formula.ipynb)
- [creating designs with NChooseK constraints](nchoosek_constraint.ipynb)